summaryrefslogtreecommitdiffstats
path: root/net.c
diff options
context:
space:
mode:
authorRainer Gerhards <rgerhards@adiscon.com>2007-12-26 17:54:54 +0000
committerRainer Gerhards <rgerhards@adiscon.com>2007-12-26 17:54:54 +0000
commitf1dceed0fee3e89f8a5a0a861d058caab4559725 (patch)
treebb25d193ce006fb2cd19b51c9a8c8647158eacc6 /net.c
parent3a68d8ec89d9cbc6eb467be85f17cf284c9e6e01 (diff)
downloadrsyslog-f1dceed0fee3e89f8a5a0a861d058caab4559725.tar.gz
rsyslog-f1dceed0fee3e89f8a5a0a861d058caab4559725.tar.xz
rsyslog-f1dceed0fee3e89f8a5a0a861d058caab4559725.zip
removed global variable LogPort
Diffstat (limited to 'net.c')
-rw-r--r--net.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/net.c b/net.c
index 4997fdd1..132a154f 100644
--- a/net.c
+++ b/net.c
@@ -855,18 +855,18 @@ dbgprintf("in closeUDPListenSockets()\n");
/* creates the UDP listen sockets
* hostname and/or LogPort may be NULL, but not both!
* bIsServer indicates if a server socket should be created
* 1 - server, 0 - client
*/
-int *create_udp_socket(uchar *hostname, uchar *LogPort, int bIsServer)
+int *create_udp_socket(uchar *hostname, uchar *pszPort, int bIsServer)
{
struct addrinfo hints, *res, *r;
int error, maxs, *s, *socks, on = 1;
int sockflags;
-dbgprintf("create_udp_socket('%s', '%s', %d);\n", hostname, LogPort, bIsServer);
- assert(!((LogPort == NULL) && (hostname == NULL)));
+dbgprintf("create_udp_socket('%s', '%s', %d);\n", hostname, pszPort, bIsServer);
+ assert(!((pszPort == NULL) && (hostname == NULL)));
memset(&hints, 0, sizeof(hints));
if(bIsServer)
hints.ai_flags = AI_PASSIVE | AI_NUMERICSERV;
@@ -874,7 +874,7 @@ dbgprintf("create_udp_socket('%s', '%s', %d);\n", hostname, LogPort, bIsServer);
hints.ai_flags = AI_NUMERICSERV;
hints.ai_family = family;
hints.ai_socktype = SOCK_DGRAM;
- error = getaddrinfo((char*) hostname, (char*) LogPort, &hints, &res);
+ error = getaddrinfo((char*) hostname, (char*) pszPort, &hints, &res);
if(error) {
logerror((char*) gai_strerror(error));
logerror("UDP message reception disabled due to error logged in last message.\n");
@@ -855,18 +855,18 @@ dbgprintf("in closeUDPListenSockets()\n");
/* creates the UDP listen sockets
- * hostname and/or LogPort may be NULL, but not both!
+ * hostname and/or pszPort may be NULL, but not both!
* bIsServer indicates if a server socket should be created
* 1 - server, 0 - client